

set -ex



pytest -vv
test ! -f /var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_8bzgurhysn/croot/conda-standalone_1715268775530/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin/codesign
exit 0
